@@ -1,5 +1,7 @@
 from dataclasses import dataclass, field
+from typing import Literal
 
+import attr
 from scrapy.item import Field, Item
 
 __all__ = [
@@ -9,17 +11,24 @@ __all__ = [
     "OldMongoDataItem",
 ]
 
+ItemModeStr = Literal["Mysql", "MongoDB"]
+# python 3.8 无法优雅地使用 LiteralString，以下用 Literal 代替
+MysqlItemModeStr = Literal["Mysql"]
+MongoDBItemModeStr = Literal["MongoDB"]
 
+
+@attr.s(auto_attribs=True)
 class ScrapyClassicItem(Item):
     """
     scrapy 经典 item 示例
     """
 
     # 用于存放所有字段信息
-    alldata = Field()
+    alldata: dict = Field()
     # 用于存放存储的表名
-    table = Field()
-    item_mode = Field()
+    table: str = Field()
+    # 用于介绍存储场景
+    item_mode: ItemModeStr = Field()
 
 
 @dataclass
@@ -38,7 +47,7 @@ class MysqlDataItem(BaseItem):
     这个是 Scrapy item 的 Mysql 的存储结构
     """
 
-    item_mode: str = field(default="Mysql")
+    item_mode: MysqlItemModeStr = field(default="Mysql")
 
 
 @dataclass
@@ -48,7 +57,7 @@ class MongoDataItem(BaseItem):
     这个 mongo_update_rule 字段是用于 Mongo 存储时作查询使用
     """
 
-    item_mode: str = field(default="MongoDB")
+    item_mode: MongoDBItemModeStr = field(default="MongoDB")
     mongo_update_rule: dict = field(default=None)
 
 
@@ -59,5 +68,5 @@ class OldMongoDataItem:
     这个 mongo_update_rule 字段是用于 Mongo 存储时作查询使用
     """
 
-    item_mode: str = field(default="MongoDB")
+    item_mode: MongoDBItemModeStr = field(default="MongoDB")
     mongo_update_rule: dict = field(default=None)
