@@ -23,8 +23,6 @@ class NormalConfig(object):
     # 项目根目录及其它所需目录
     CONFIG_DIR = dirname(abspath(__file__))
     ROOT_DIR = os.path.dirname(CONFIG_DIR)
-    LOG_DIR = join(CONFIG_DIR, "logs")
-    DOC_DIR = join(CONFIG_DIR, "docs")
     COMMON_DIR = join(CONFIG_DIR, "common")
     VIT_DIR = join(CONFIG_DIR, "VIT")
 
